@@ -3,7 +3,7 @@
  */
 
 /*
- * Copyright (C) 1986, 1988, 1989, 1991-2025,
+ * Copyright (C) 1986, 1988, 1989, 1991-2026,
  * the Free Software Foundation, Inc.
  *
  * This file is part of GAWK, the GNU implementation of the
@@ -1131,6 +1131,7 @@ do_print(int nargs, int redirtype)
 
 	if (redirtype != 0) {
 		redir_exp = PEEK(nargs);
+		redir_exp = elem_new_to_scalar(redir_exp);
 		if (redir_exp->type != Node_val)
 			fatal(_("attempt to use array `%s' in a scalar context"), array_vname(redir_exp));
 		rp = redirect(redir_exp, redirtype, & errflg, true);
@@ -1599,7 +1600,7 @@ do_match(int nargs)
 		lintwarn(_("%s: received non-string first argument"), "match");
 
 	rstart = research(rp, t1->stptr, 0, t1->stlen, RE_NEED_START|RE_NEED_SUB);
-	if (rstart >= 0) {	/* match succeded */
+	if (rstart >= 0) {	/* match succeeded */
 		size_t *wc_indices = NULL;
 
 		rlength = REEND(rp, t1->stptr) - RESTART(rp, t1->stptr);	/* byte length */
@@ -2755,7 +2756,7 @@ floating_point_hex:
 		save = str[len];
 		str[len] = '\0';
 		if (is_hex_float
-		    && strchr(str, 'p') == NULL 
+		    && strchr(str, 'p') == NULL
 		    && strchr(str, 'P') == NULL)
 			fatal(_("hexadecimal floating point constants require an exponent"));
 		retval = strtod(str, endptr);
@@ -3436,7 +3437,9 @@ do_dump_node(int nargs)
 	printf("MB_CUR_MAX = %u\n", (int) MB_CUR_MAX);
 	printf("sizeof(int) = %zu\n", sizeof(int));
 	printf("sizeof(long) = %zu\n", sizeof(long));
+#ifdef HAVE_LONG_LONG_INT
 	printf("sizeof(long long) = %zu\n", sizeof(long long));
+#endif
 	printf("sizeof(void *) = %zu\n", sizeof(void *));
 	printf("\n");
 	fflush(stdout);
@@ -3502,6 +3505,6 @@ do_dump_node(int nargs)
 	fprintf(fp, "%zu\txarray\n", offsetof(NODE, xarray));
 
 	pclose(fp);
-	
+
 	return Nnull_string;
 }
